@@ -6,7 +6,6 @@ import arrow
 from cached_property import cached_property
 
 from canvas_workflow_kit import events
-from canvas_workflow_kit.builtin_cqms.diabetes_quality_measure import DiabetesQualityMeasure
 from canvas_workflow_kit.protocol import (
     STATUS_DUE,
     STATUS_SATISFIED,
@@ -21,6 +20,7 @@ from canvas_workflow_kit.value_set.v2018 import (
     DietaryRecommendations,
     Hba1CLaboratoryTest
 )
+from workflow_sdk_loader.builtin_cqms.diabetes_quality_measure import DiabetesQualityMeasure
 
 
 class ClinicalQualityMeasure122v6(ExternallyAwareClinicalQualityMeasure, DiabetesQualityMeasure):
