@@ -28,6 +28,14 @@ def green(string: str) -> str:
     return click.style(string, fg='green')
 
 
+def blue(string: str) -> str:
+    return click.style(string, fg='blue', bold=True)
+
+
+def cyan(string: str) -> str:
+    return click.style(string, fg='cyan', bold=True)
+
+
 def yellow(string: str) -> str:
     return click.style(string, fg='yellow', bold=True)
 
@@ -39,9 +47,10 @@ def red(string: str) -> str:
 def get_settings_path() -> Path:
     return Path.home() / '.canvas' / 'config.ini'
 
-
 # Settings ---------------
 #
+
+
 def read_settings(ctx) -> Dict[str, Any]:
 
     try:
@@ -257,7 +266,12 @@ def _process_fixture_from_patient(ctx, patient_key, output_directory):
 @click.option('--date')
 @click.option('--start-date')
 @click.option('--end-date')
-def test_fixture(module_path: str, fixture_folder: str, date: str = None, start_date: str = None, end_date: str = None):
+@click.option('--full', flag_value='full', default=False, help="Show the full output returned to the application.")
+def test_fixture(
+    module_path: str, fixture_folder: str,
+    date: str = None, start_date: str = None, end_date: str = None,
+    full: bool = False
+):
     """
     Test a python file with a ClinicalQualityMeasure against a fixture folder.
     """
@@ -274,18 +288,23 @@ def test_fixture(module_path: str, fixture_folder: str, date: str = None, start_
     subdirectories = [x for x in path.iterdir() if x.is_dir()]
 
     if subdirectories:
-        for fixture_folder in subdirectories:
-            test_fixture_directory(fixture_folder, Class, date, start_date, end_date)
-            click.echo()
+        for i, fixture_folder in enumerate(subdirectories):
+            if i >= 1:
+                click.echo('-' * 80)
+            test_fixture_directory(fixture_folder, Class, date, start_date, end_date, full)
+
     else:
-        test_fixture_directory(path, Class, date, start_date, end_date)
+        test_fixture_directory(path, Class, date, start_date, end_date, full)
 
 
-def test_fixture_directory(fixture_folder: Path, Class: type, date: str = None, start_date: str = None, end_date: str = None):
+def test_fixture_directory(
+    fixture_folder: Path, Class: type,
+    date: str = None, start_date: str = None, end_date: str = None,
+    full: bool = False
+):
     # 2. load JSON folder of fixture data
     fixture_title = f"Fixture: {yellow(fixture_folder.name)}"
 
-    click.echo('-' * 80)
     click.echo(fixture_title)
 
     patient = load_patient(Path(fixture_folder))
@@ -312,11 +331,19 @@ def test_fixture_directory(fixture_folder: Path, Class: type, date: str = None,
     results = protocol.compute_results()
 
     # 4. return results
-    results.recommendations = [vars(r) for r in results.recommendations]
-    if not results.recommendations:
+    recommendations = getattr(results, 'recommendations', None)
+    if not recommendations:
         click.echo(red("No recommendations"))
-    else:
+
+    elif full:
+        recommendations = [vars(r) for r in recommendations]
         click.echo(json.dumps(vars(results), indent=2))
+    else:
+        for r in recommendations:
+            click.echo(cyan(r.__class__.__name__))
+            for attr in ('title', 'key', 'button'):
+                if hasattr(r, attr):
+                    click.echo(f' {blue(attr.capitalize())}: {getattr(r, attr)}')
 
 
 @cli.command()
