@@ -89,11 +89,13 @@ class CHANGE_TYPE:
 
 class AlertPlacement(Enum):
     ALERT_PLACEMENT_CHART = 'chart'
-    ALERT_PLACEMENT_SCHEDULING = 'scheduling'
+    ALERT_PLACEMENT_TIMELINE = 'timeline'
     ALERT_PLACEMENT_APPOINTMENT_CARD = 'appointment_card'
+    ALERT_PLACEMENT_SCHEDULING_CARD = 'scheduling_card'
     ALERT_PLACEMENT_PROFILE = 'profile'
 
 
 class AlertIntent(Enum):
-    ALERT_INTENT_NEUTRAL = 'info'
+    ALERT_INTENT_INFO = 'info'
     ALERT_INTENT_WARNING = 'warning'
+    ALERT_INTENT_ALERT = 'alert'
