@@ -620,6 +620,18 @@ class ReferralRecordSet(PatientEventRecordSet):
     API_UPDATE_FIELD = 'referrals'
 
 
+class InpatientStayRecordSet(PatientEventRecordSet):
+    # TO BE DEVELOPED
+    VALID_SYSTEMS: List[str] = [
+        'snomedct',
+        'loinc',
+        'cpt',
+    ]
+    DATE_FIELD = 'noteTimestamp'
+    PATIENT_FIELD = 'inpatientStay'
+    API_UPDATE_FIELD = 'inpatientStay'
+
+
 class ImagingReportRecordSet(PatientEventRecordSet):
     VALID_SYSTEMS: List[str] = [
         'snomedct',
