@@ -150,12 +150,14 @@ class ProtocolSource(object):
 
 class Protocol(metaclass=DeclarativeFieldsMetaclass):
 
-    compute_on_change_types: List[str] = []
-    responds_to_event_types: List[str] = []
-    identifiers: List[str] = []
-    title: str = ''
-    description: str = ''
-    information: str = ''
+    class Meta:
+        title: str = ''
+        compute_on_change_types: List[str] = []
+        responds_to_event_types: List[str] = []
+        identifiers: List[str] = []
+        description: str = ''
+        information: str = ''
+        references: List[str] = []
 
     def __init__(self, patient: Patient, **kwargs):
         self.patient = patient
@@ -171,15 +173,6 @@ class Protocol(metaclass=DeclarativeFieldsMetaclass):
         """
         return cls.__name__
 
-    @classmethod
-    def revision(cls) -> str:
-        # Dpreecated - use Class.version instead.
-        raise NotImplementedError('revision must be overridden')
-
-    @property
-    def references(self) -> List[str]:
-        raise NotImplementedError('references must be overridden')
-
     @staticmethod
     def relative_float(value: str) -> float:
         try:
@@ -199,7 +192,7 @@ class Protocol(metaclass=DeclarativeFieldsMetaclass):
         """
         sources = []
 
-        for ref in self.references:
+        for ref in self._meta.references:
             # look for URL at the end of the text
             match = PROTOCOL_SOURCE_URL_RE.search(ref)
 
@@ -262,11 +255,10 @@ class ClinicalQualityMeasure(Protocol):
     CHANGE_SUSPECT_HCC = CHANGE_TYPE.SUSPECT_HCC
     CHANGE_VITAL_SIGN = CHANGE_TYPE.VITAL_SIGN
 
-    data_sources: List[str] = []
-
-    responds_to_event_types = [
-        events.HEALTH_MAINTENANCE,
-    ]
+    class Meta:
+        responds_to_event_types = [
+            events.HEALTH_MAINTENANCE,
+        ]
 
     def __init__(self,
                  change_types: List = None,
