@@ -1605,7 +1605,7 @@ class TestProtocolOverrideRecordSet(TestCase):
     def test_constants(self):
         tested = ProtocolOverrideRecordSet([])
         self.assertIsInstance(tested, PatientRecordSet)
-        self.assertEqual(['cnvs'], tested.VALID_SYSTEMS)
+        self.assertEqual(['snomedct'], tested.VALID_SYSTEMS)
         self.assertEqual('protocol_overrides', tested.PATIENT_FIELD)
         self.assertEqual('patient__key', tested.API_KEY_FIELD)
         self.assertEqual('protocolOverrides', tested.API_UPDATE_FIELD)
@@ -1619,7 +1619,10 @@ class TestProtocolOverrideRecordSet(TestCase):
             },
             'snooze': {
                 'reference': '2018-10-01T00:00:00Z',
-                'snoozedDays': 22
+                'snoozedDays': 22,
+                'reasonCode': '413311005',
+                'reasonText': 'PATIENT_REFUSED',
+                'reasonCodeSystem': 'snomedct'
             },
             'modified': '2018-10-02T21:50:09.661490Z'
         }])  # yapf: disable
@@ -1632,7 +1635,10 @@ class TestProtocolOverrideRecordSet(TestCase):
             },
             'snooze': {
                 'reference': '2018-10-01T00:00:00Z',
-                'snoozedDays': 22
+                'snoozedDays': 22,
+                'reasonCode': '413311005',
+                'reasonText': 'PATIENT_REFUSED',
+                'reasonCodeSystem': 'snomedct'
             },
             'modified': '2018-10-02T21:50:09.661490Z'
         }])  # yapf: disable
@@ -1645,7 +1651,10 @@ class TestProtocolOverrideRecordSet(TestCase):
                 'adjustment': None,
                 'snooze': {
                     'reference': '2018-09-15T00:00:00Z',
-                    'snoozedDays': 12
+                    'snoozedDays': 12,
+                    'reasonCode': '413311005',
+                    'reasonText': 'PATIENT_REFUSED',
+                    'reasonCodeSystem': 'snomedct'
                 },
                 'modified': '2018-09-15T21:50:09.661490Z'
             },
@@ -1657,7 +1666,10 @@ class TestProtocolOverrideRecordSet(TestCase):
                 },
                 'snooze': {
                     'reference': arrow.now(),
-                    'snoozedDays': 22
+                    'snoozedDays': 22,
+                    'reasonCode': '413311005',
+                    'reasonText': 'PATIENT_REFUSED',
+                    'reasonCodeSystem': 'snomedct'
                 },
                 'modified': '2018-10-02T21:50:09.661490Z'
             },
@@ -1666,7 +1678,10 @@ class TestProtocolOverrideRecordSet(TestCase):
                 'adjustment': None,
                 'snooze': {
                     'reference': '2018-09-15T00:00:00Z',
-                    'snoozedDays': 12
+                    'snoozedDays': 12,
+                    'reasonCode': '413311005',
+                    'reasonText': 'PATIENT_REFUSED',
+                    'reasonCodeSystem': 'snomedct'
                 },
                 'modified': '2018-09-15T21:50:09.661490Z'
             },
@@ -1707,14 +1722,17 @@ class TestProtocolOverrideRecordSet(TestCase):
             },
             'snooze': {
                 'reference': arrow.now(),
-                'snoozedDays': 22
+                'snoozedDays': 22,
+                'reasonCode': '413311005',
+                'reasonText': 'PATIENT_REFUSED',
+                'reasonCodeSystem': 'snomedct'
             },
             'modified': '2018-10-02T21:50:09.661490Z'
         }  # yapf: disable
         expected = [
             {
-                'code': 'TEST001v2',
-                'system': 'cnvs'
+                'code': '413311005',
+                'system': 'snomedct'
             },
         ]
         self.assertEqual(expected, ProtocolOverrideRecordSet.item_to_codes(item))
